==> glpi-9.2.1.tgz: glpi/front/planning.form.php <==
<?php
/**
 * ---------------------------------------------------------------------
 * GLPI - Gestionnaire Libre de Parc Informatique
 * Copyright (C) 2015-2017 Teclib' and contributors.
 *
 * http://glpi-project.org
 *
 * based on GLPI - Gestionnaire Libre de Parc Informatique
 * Copyright (C) 2003-2014 by the INDEPNET Development Team.
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * GLPI is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GLPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 * ---------------------------------------------------------------------
 */

/** @file
* @brief
* @since version 9.1
*/

include ('../inc/includes.php');

Session::checkLoginUser();

if ($_REQUEST["action"] == "send_add_user_form") {
   Planning::sendAddUserForm($_REQUEST);
}

if ($_REQUEST["action"] == "send_add_group_users_form") {
   Planning::sendAddGroupUsersForm($_REQUEST);
}

if ($_REQUEST["action"] == "send_add_group_form") {
   Planning::sendAddGroupForm($_REQUEST);
}

Html::back();

==> glpi-9.5.7.tgz: glpi/front/planning.form.php <==
<?php
/**
 * ---------------------------------------------------------------------
 * GLPI - Gestionnaire Libre de Parc Informatique
 * Copyright (C) 2015-2022 Teclib' and contributors.
 *
 * http://glpi-project.org
 *
 * based on GLPI - Gestionnaire Libre de Parc Informatique
 * Copyright (C) 2003-2014 by the INDEPNET Development Team.
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * GLPI is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GLPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 * ---------------------------------------------------------------------
 */

/**
 * @since 9.1
 */

include ('../inc/includes.php');

Session::checkLoginUser();

if ($_REQUEST["action"] == "send_add_user_form") {
   Planning::sendAddUserForm($_REQUEST);
}

if ($_REQUEST["action"] == "send_add_group_users_form") {
   Planning::sendAddGroupUsersForm($_REQUEST);
}

if ($_REQUEST["action"] == "send_add_group_form") {
   Planning::sendAddGroupForm($_REQUEST);
}

if ($_REQUEST["action"] == "send_add_external_form") {
   Planning::sendAddExternalForm($_REQUEST);
}

Html::back();
